# Script for creating read only user for MongoDB, PostgreSQL, Redis
## PostgresQL
- `create-read-user postgres --uri Postgres_URI -u USERNAME -p PASSWORD `
## Redis
- `create-read-user redis --uri Redis_URI -u USERNAME -p PASSWORD `
## MongoDB
- `create-read-user mongodb --uri Mongo_URI -u USERNAME -p PASSWORD `